package com.huashe.park.core.service.impl;


import com.huashe.common.annotation.DataSource;
import com.huashe.common.enums.DataSourceType;
import com.huashe.park.core.mapper.BdDevcTrailMapper;
import com.huashe.park.core.service.IBdDevcTrailService;
import com.huashe.park.domain.entity.BdDevcTrail;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.List;

/**
 * 设备轨迹Service业务层处理
 * 
 * @author ruoyi
 * @date 2024-11-07
 */
@Service
@DataSource(DataSourceType.PKB)
public class BdDevcTrailServiceImpl implements IBdDevcTrailService
{
    @Autowired
    private BdDevcTrailMapper bdDevcTrailMapper;

    /**
     * 查询设备轨迹
     * 
     * @param id 设备轨迹主键
     * @return 设备轨迹
     */
    @Override
    public BdDevcTrail selectBdDevcTrailById(Long id)
    {
        return bdDevcTrailMapper.selectBdDevcTrailById(id);
    }

    /**
     * 查询设备轨迹列表
     * 
     * @param bdDevcTrail 设备轨迹
     * @return 设备轨迹
     */
    @Override
    public List<BdDevcTrail> selectBdDevcTrailList(BdDevcTrail bdDevcTrail)
    {
        return bdDevcTrailMapper.selectBdDevcTrailList(bdDevcTrail);
    }

    /**
     * 新增设备轨迹
     * 
     * @param bdDevcTrail 设备轨迹
     * @return 结果
     */
    @Override
    public int insertBdDevcTrail(BdDevcTrail bdDevcTrail)
    {
        return bdDevcTrailMapper.insertBdDevcTrail(bdDevcTrail);
    }

    /**
     * 修改设备轨迹
     * 
     * @param bdDevcTrail 设备轨迹
     * @return 结果
     */
    @Override
    public int updateBdDevcTrail(BdDevcTrail bdDevcTrail)
    {
        return bdDevcTrailMapper.updateBdDevcTrail(bdDevcTrail);
    }

    /**
     * 批量删除设备轨迹
     * 
     * @param ids 需要删除的设备轨迹主键
     * @return 结果
     */
    @Override
    public int deleteBdDevcTrailByIds(Long[] ids)
    {
        return bdDevcTrailMapper.deleteBdDevcTrailByIds(ids);
    }

    /**
     * 删除设备轨迹信息
     * 
     * @param id 设备轨迹主键
     * @return 结果
     */
    @Override
    public int deleteBdDevcTrailById(Long id)
    {
        return bdDevcTrailMapper.deleteBdDevcTrailById(id);
    }
}
